import { Container } from "@material-ui/core";
import React from "react";
import { makeStyles } from "@material-ui/core/styles";
import QuestionAnswersList from "./QuestionAnswerList";
import { Route, Switch } from "react-router-dom";
import { PersonRoutes } from "./Main";
import { MenuOption } from "./MainMenu";
import QuestionAnswerIcon from "@material-ui/icons/QuestionAnswer";

const useStyles = makeStyles((theme) => ({
  container: {
    paddingTop: theme.spacing(4),
    paddingBottom: theme.spacing(4),
    flexDirection: "column",
  },
}));

interface CandidateRoutes extends PersonRoutes {
  question: MenuOption;
}

export const candidateRoutes: CandidateRoutes = {
  question: {
    title: "Fragen beantworten",
    path: "/",
    icon: <QuestionAnswerIcon />,
  },
};

interface HomePageCandidateProps {
  loggedInPersonRowId: number;
}

export function HomePageCandidate(
  props: HomePageCandidateProps
): React.ReactElement {
  const classes = useStyles();

  return (
    <Container maxWidth="lg" className={classes.container}>
      <Switch>
        <Route exact path={candidateRoutes.question.path}>
          <QuestionAnswersList
            loggedInPersonRowId={props.loggedInPersonRowId}
          />
        </Route>
      </Switch>
    </Container>
  );
}
